@@ -1,5 +1,8 @@
 #define ZERO 0
 # define ONE 1
 
+extern int GLOBAL;
+
 int zero();
 int one();
+int global();
